'use strict';

function getComponentName(opts) {
  return opts && (opts.Ctor.options.name || opts.tag);
}

function isDef(v) {
  return v !== undefined && v !== null;
}

function isAsyncPlaceholder(node) {
  return node.isComment && node.asyncFactory;
}

function getFirstComponentChild(children) {
  if (Array.isArray(children)) {
    for (var i = 0; i < children.length; i++) {
      var c = children[i];

      if (isDef(c) && (isDef(c.componentOptions) || isAsyncPlaceholder(c))) {
        return c;
      }
    }
  }
}

var Cache = {
  name: 'v-cache',
  abstract: true,
  props: {
    cacheKey: {
      type: String,
      required: true
    }
  },
  data: function data() {
    return {
      cache: Object.create(null)
    };
  },
  render: function render() {
    var slot = this.$slots.default;
    var vnode = getFirstComponentChild(slot);
    var componentOptions = vnode && vnode.componentOptions;

    if (componentOptions) {
      var name = getComponentName(componentOptions);
      var cache = this.cache,
          cacheKey = this.cacheKey;
      var key = name + cacheKey;
      vnode.key = key;

      if (cache[key]) {
        vnode.componentInstance = cache[key].componentInstance;
      } else {
        cache[key] = vnode;
      }

      vnode.data.keepAlive = true;
    }

    return vnode || slot && slot[0];
  },
  destroyed: function destroyed() {
    Object.values(this.cache).forEach(function (vnode) {
      vnode.componentInstance.$destroy();
    });
  }
};

function VueCache(Vue) {
  Vue.component(Cache.name, Cache);
}

if (typeof window !== 'undefined' && window.Vue) {
  VueCache(window.Vue);
}

module.exports = VueCache;
